pub fn capability_cache_entry(binary: &Path) -> Option<CodexCapabilities>Expand description
Returns the cached capabilities for a specific binary path if present.
pub fn capability_cache_entry(binary: &Path) -> Option<CodexCapabilities>Returns the cached capabilities for a specific binary path if present.