pub struct AddAppRuntimeRequest {
pub name: String,
pub definition: AppRuntimeDefinition,
pub overwrite: bool,
}Expand description
Input for adding or updating an app runtime entry.
Fields
name: Stringdefinition: AppRuntimeDefinitionoverwrite: boolTrait Implementations
Sourceimpl Clone for AddAppRuntimeRequest
impl Clone for AddAppRuntimeRequest
Sourcefn clone(&self) -> AddAppRuntimeRequest
fn clone(&self) -> AddAppRuntimeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddAppRuntimeRequest
impl Debug for AddAppRuntimeRequest
Sourceimpl<'de> Deserialize<'de> for AddAppRuntimeRequest
impl<'de> Deserialize<'de> for AddAppRuntimeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AddAppRuntimeRequest
impl PartialEq for AddAppRuntimeRequest
Sourcefn eq(&self, other: &AddAppRuntimeRequest) -> bool
fn eq(&self, other: &AddAppRuntimeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AddAppRuntimeRequest
impl Serialize for AddAppRuntimeRequest
impl StructuralPartialEq for AddAppRuntimeRequest