pub struct CodexAppServer { /* private fields */ }Expand description
Client wrapper around the stdio app-server.
Implementations
Sourceimpl CodexAppServer
impl CodexAppServer
Sourcepub async fn start(
config: StdioServerConfig,
client: ClientInfo,
) -> Result<Self, McpError>
pub async fn start( config: StdioServerConfig, client: ClientInfo, ) -> Result<Self, McpError>
Launch codex app-server, issue initialize, and return a connected handle.
Sourcepub async fn start_experimental(
config: StdioServerConfig,
client: ClientInfo,
) -> Result<Self, McpError>
pub async fn start_experimental( config: StdioServerConfig, client: ClientInfo, ) -> Result<Self, McpError>
Launch with capabilities.experimentalApi=true in the initialize handshake.
Sourcepub async fn with_capabilities(
config: StdioServerConfig,
client: ClientInfo,
capabilities: Value,
) -> Result<Self, McpError>
pub async fn with_capabilities( config: StdioServerConfig, client: ClientInfo, capabilities: Value, ) -> Result<Self, McpError>
Launch with explicit capabilities to send during initialize.
Sourcepub async fn thread_start(
&self,
params: ThreadStartParams,
) -> Result<AppCallHandle, McpError>
pub async fn thread_start( &self, params: ThreadStartParams, ) -> Result<AppCallHandle, McpError>
Start a new thread (or use a provided ID) via thread/start.
Sourcepub async fn thread_resume(
&self,
params: ThreadResumeParams,
) -> Result<AppCallHandle, McpError>
pub async fn thread_resume( &self, params: ThreadResumeParams, ) -> Result<AppCallHandle, McpError>
Resume an existing thread via thread/resume.
Sourcepub async fn thread_list(
&self,
params: ThreadListParams,
) -> Result<ThreadListResponse, McpError>
pub async fn thread_list( &self, params: ThreadListParams, ) -> Result<ThreadListResponse, McpError>
List threads via thread/list.
Sourcepub async fn thread_fork(
&self,
params: ThreadForkParams,
) -> Result<ThreadForkResponse, McpError>
pub async fn thread_fork( &self, params: ThreadForkParams, ) -> Result<ThreadForkResponse, McpError>
Fork an existing thread via thread/fork.
Sourcepub async fn turn_start(
&self,
params: TurnStartParams,
) -> Result<AppCallHandle, McpError>
pub async fn turn_start( &self, params: TurnStartParams, ) -> Result<AppCallHandle, McpError>
Start a new turn on a thread via turn/start.
Sourcepub async fn turn_start_v2(
&self,
params: TurnStartParamsV2,
) -> Result<AppCallHandle, McpError>
pub async fn turn_start_v2( &self, params: TurnStartParamsV2, ) -> Result<AppCallHandle, McpError>
Start a new turn on a thread via turn/start (pinned fork flow subset).
Sourcepub async fn select_last_thread_id(
&self,
cwd: PathBuf,
) -> Result<Option<String>, McpError>
pub async fn select_last_thread_id( &self, cwd: PathBuf, ) -> Result<Option<String>, McpError>
Select the deterministic “last” thread id using thread/list paging and tuple ordering.
Sourcepub async fn turn_interrupt(
&self,
params: TurnInterruptParams,
) -> Result<AppCallHandle, McpError>
pub async fn turn_interrupt( &self, params: TurnInterruptParams, ) -> Result<AppCallHandle, McpError>
Interrupt an active turn via turn/interrupt.