pub struct ResolvedStreamableHttpDefinition {
pub url: String,
pub headers: BTreeMap<String, String>,
pub bearer_env_var: Option<String>,
pub bearer_token: Option<String>,
pub connect_timeout_ms: Option<u64>,
pub request_timeout_ms: Option<u64>,
}Expand description
HTTP runtime config with bearer tokens resolved from the environment.
Fields
url: Stringheaders: BTreeMap<String, String>bearer_env_var: Option<String>bearer_token: Option<String>connect_timeout_ms: Option<u64>request_timeout_ms: Option<u64>Trait Implementations
Sourceimpl Clone for ResolvedStreamableHttpDefinition
impl Clone for ResolvedStreamableHttpDefinition
Sourcefn clone(&self) -> ResolvedStreamableHttpDefinition
fn clone(&self) -> ResolvedStreamableHttpDefinition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ResolvedStreamableHttpDefinition
impl<'de> Deserialize<'de> for ResolvedStreamableHttpDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ResolvedStreamableHttpDefinition> for StreamableHttpConnector
impl From<ResolvedStreamableHttpDefinition> for StreamableHttpConnector
Sourcefn from(definition: ResolvedStreamableHttpDefinition) -> Self
fn from(definition: ResolvedStreamableHttpDefinition) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ResolvedStreamableHttpDefinition
impl PartialEq for ResolvedStreamableHttpDefinition
Sourcefn eq(&self, other: &ResolvedStreamableHttpDefinition) -> bool
fn eq(&self, other: &ResolvedStreamableHttpDefinition) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvedStreamableHttpDefinition
impl StructuralPartialEq for ResolvedStreamableHttpDefinition