OutputSchemaFile

Struct OutputSchemaFile 

pub struct OutputSchemaFile { /* private fields */ }
Temporary on-disk output schema file passed to codex --output-schema.

The underlying temporary directory is kept alive by this struct and cleaned up automatically when dropped.

Implementations

Source

impl OutputSchemaFile

pub fn path(&self) -> &Path

Returns the filesystem path of the generated schema file.

Example
use codex::output_schema_file::create_output_schema_file;
use serde_json::json;

let file = create_output_schema_file(Some(&json!({"type":"object"})))?
    .expect("schema file should exist");
assert!(file.path().exists());