pub struct OutputSchemaFile { /* private fields */ }Expand description
Temporary on-disk output schema file passed to codex --output-schema.
The underlying temporary directory is kept alive by this struct and cleaned up automatically when dropped.
Implementations
Sourceimpl OutputSchemaFile
impl OutputSchemaFile
Sourcepub fn path(&self) -> &Path
pub fn path(&self) -> &Path
Returns the filesystem path of the generated schema file.
Example
use codex::output_schema_file::create_output_schema_file;
use serde_json::json;
let file = create_output_schema_file(Some(&json!({"type":"object"})))?
.expect("schema file should exist");
assert!(file.path().exists());Auto Trait Implementations
impl Freeze for OutputSchemaFile
impl RefUnwindSafe for OutputSchemaFile
impl Send for OutputSchemaFile
impl Sync for OutputSchemaFile
impl Unpin for OutputSchemaFile
impl UnsafeUnpin for OutputSchemaFile
impl UnwindSafe for OutputSchemaFile